# tahini

|Service|Status|
| -------------: | :---- |
| Testing        | ![Python package](https://github.com/tahini-dev/tahini/workflows/Python%20package/badge.svg) |
| Coverage       | [![Codecov branch](https://img.shields.io/codecov/c/github/ibis-project/ibis/master.svg)](https://codecov.io/gh/ibis-project/ibis) |

Package for graph theory

## Goals

- Learn
- Have fun
- Write python implementation (classes) for graph theory
- Update to cython implementation for graph theory for speed
- Write graph theory algorithm